summaryrefslogtreecommitdiffstats
path: root/kdeui/kdatetbl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdeui/kdatetbl.cpp')
-rw-r--r--kdeui/kdatetbl.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kdeui/kdatetbl.cpp b/kdeui/kdatetbl.cpp
index 416bd66b1..e4f1ae988 100644
--- a/kdeui/kdatetbl.cpp
+++ b/kdeui/kdatetbl.cpp
@@ -536,7 +536,7 @@ KDateTable::setDate(const TQDate& date_)
numDaysPrevMonth=calendar->daysInMonth(temp);
if(changed)
{
- tqrepaintContents(false);
+ repaintContents(false);
}
return true;
}
@@ -547,16 +547,16 @@ KDateTable::getDate() const
return date;
}
// what are those tqrepaintContents() good for? (pfeiffer)
void KDateTable::focusInEvent( TQFocusEvent *e )
{
-// tqrepaintContents(false);
+// repaintContents(false);
TQGridView::focusInEvent( e );
}
void KDateTable::focusOutEvent( TQFocusEvent *e )
{
-// tqrepaintContents(false);
+// repaintContents(false);
TQGridView::focusOutEvent( e );
}
@@ -547,16 +547,16 @@ KDateTable::getDate() const
return date;
}
-// what are those tqrepaintContents() good for? (pfeiffer)
+// what are those repaintContents() good for? (pfeiffer)
void KDateTable::focusInEvent( TQFocusEvent *e )
{